@@ -16,6 +16,5 @@ from .analysis import Analysis
 
 
 class AnalysisDS(Analysis, DataSourceCursor):
-    
-    """Combine a standard DataSourceCursor with Analysis.
-    """
+
+    """Combine a standard DataSourceCursor with Analysis."""
