@@ -16,7 +16,7 @@ from solentware_base.core.where import (
     OR,
     NOT,
     AND,
-    )
+)
 
 from chessql.core import cql
 from chessql.core.cql import Token
@@ -28,16 +28,16 @@ from chessql.core.constants import (
     WHITE_PIECE_NAMES,
     BLACK_PIECE_NAMES,
     EMPTY_SQUARE_NAME,
-    )
+)
 
 from pgn_read.core.constants import (
     FEN_WHITE_KING,
-    )
+)
 from pgn_read.core.squares import Squares
 
 from ..core.constants import (
     MOVE_NUMBER_KEYS,
-    )
+)
 from .rayfilter import RayFilter, move_number_str
 from ..core.filespec import (
     PIECESQUAREMOVE_FIELD_DEF,
@@ -47,33 +47,40 @@ from ..core.filespec import (
     PARTIAL_FILE_DEF,
     NEWGAMES_FIELD_VALUE,
     PARTIALPOSITION_FIELD_DEF,
-    )
+)
 from ..core.chessrecord import ChessDBrecordGameUpdate
 
 # The immediate children of nodes with the names of these filters have 'and'
 # and 'or' applied to evaluate the node's answer.
 _AND_FILTERS = frozenset(
-    (Token.AND,
-     cql.LEFTBRACE_NUMBER,
-     cql.LEFTBRACE_POSITION,
-     cql.LEFTBRACE_SET,
-     cql.LEFTBRACE_LOGICAL,
-     Token.CQL,
-     ))
+    (
+        Token.AND,
+        cql.LEFTBRACE_NUMBER,
+        cql.LEFTBRACE_POSITION,
+        cql.LEFTBRACE_SET,
+        cql.LEFTBRACE_LOGICAL,
+        Token.CQL,
+    )
+)
 _OR_FILTERS = frozenset(
-    (Token.OR,
-     Token.FLIP,
-     Token.FLIPHORIZONTAL,
-     Token.FLIPVERTICAL,
-     Token.FLIPCOLOR,
-     Token.ROTATE45,
-     Token.ROTATE90,
-     Token.SHIFT,
-     Token.SHIFTHORIZONTAL,
-     Token.SHIFTVERTICAL,
-     ))
+    (
+        Token.OR,
+        Token.FLIP,
+        Token.FLIPHORIZONTAL,
+        Token.FLIPVERTICAL,
+        Token.FLIPCOLOR,
+        Token.ROTATE45,
+        Token.ROTATE90,
+        Token.SHIFT,
+        Token.SHIFTHORIZONTAL,
+        Token.SHIFTVERTICAL,
+    )
+)
 
-_filters = {Token.PIECE_DESIGNATOR, Token.RAY,}
+_filters = {
+    Token.PIECE_DESIGNATOR,
+    Token.RAY,
+}
 _SUPPORTED_FILTERS = frozenset(_AND_FILTERS.union(_OR_FILTERS.union(_filters)))
 del _filters
 
@@ -83,9 +90,8 @@ class ChessQLGamesError(Exception):
 
 
 class ChessQLGames:
-    
-    """Represent subset of games that match a Chess Query Language query.
-    """
+
+    """Represent subset of games that match a Chess Query Language query."""
 
     def __init__(self, *a, **k):
         super().__init__(*a, **k)
@@ -98,36 +104,37 @@ class ChessQLGames:
         # attributes might be better.
         # The 'try ...' statements in .gui.cqldisplay and .gui.cqltext fit the
         # version of Find(...) call with the recordclass argument.
-        #self.cqlfinder = Find(
+        # self.cqlfinder = Find(
         #    self.dbhome, self.dbset, recordclass=ChessDBrecordGameUpdate)
         self.cqlfinder = Find(self.dbhome, self.dbset)
 
         self.not_implemented = set()
 
-    def forget_cql_statement_games(
-        self, sourceobject, commit=True):
+    def forget_cql_statement_games(self, sourceobject, commit=True):
         """Forget game records matching ChessQL statement.
 
         sourceobject is partial position record instance for cql query.
         commit indicates if this method should start and commit transaction.
-        
+
         """
         # Forget the list of games under the query key.
         ppview = self.dbhome.recordlist_record_number(
-            PARTIAL_FILE_DEF,
-            key=sourceobject.key.recno)
+            PARTIAL_FILE_DEF, key=sourceobject.key.recno
+        )
         if commit:
             self.dbhome.start_transaction()
         self.dbhome.unfile_records_under(
             self.dbset,
             PARTIALPOSITION_FIELD_DEF,
-            self.dbhome.encode_record_number(sourceobject.key.recno))
+            self.dbhome.encode_record_number(sourceobject.key.recno),
+        )
 
         # Remove query from set that needs recalculating.
         changed = self.dbhome.recordlist_key(
             PARTIAL_FILE_DEF,
             NEWGAMES_FIELD_DEF,
-            key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE))
+            key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE),
+        )
         changed.remove_recordset(ppview)
 
         self.dbhome.file_records_under(
@@ -135,18 +142,19 @@ class ChessQLGames:
             NEWGAMES_FIELD_DEF,
             changed,
             self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE),
-            )
+        )
         if commit:
             self.dbhome.commit()
 
     def update_cql_statement_games(
-        self, sourceobject, initial_recordset=None, commit=True):
+        self, sourceobject, initial_recordset=None, commit=True
+    ):
         """Find game records matching ChessQL statement and store on database.
 
         sourceobject is partial position record instance for cql query.
         initial_recordset is games to which query is applied
         commit indicates if this method should start and commit transaction.
-        
+
         """
         assert sourceobject is not None
         # Evaluate query.
@@ -158,25 +166,28 @@ class ChessQLGames:
         query = sourceobject.value
         games = self.get_games_matching_filters(
             query,
-            self.get_games_matching_parameters(query, initial_recordlist))
+            self.get_games_matching_parameters(query, initial_recordlist),
+        )
 
         # File the list of games under the query key.
         ppview = self.dbhome.recordlist_record_number(
-            PARTIAL_FILE_DEF,
-            key=sourceobject.key.recno)
+            PARTIAL_FILE_DEF, key=sourceobject.key.recno
+        )
         if commit:
             self.dbhome.start_transaction()
         self.dbhome.file_records_under(
             self.dbset,
             PARTIALPOSITION_FIELD_DEF,
             games,
-            self.dbhome.encode_record_number(sourceobject.key.recno))
+            self.dbhome.encode_record_number(sourceobject.key.recno),
+        )
 
         # Remove query from set that needs recalculating.
         changed = self.dbhome.recordlist_key(
             PARTIAL_FILE_DEF,
             NEWGAMES_FIELD_DEF,
-            key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE))
+            key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE),
+        )
         changed.remove_recordset(ppview)
 
         self.dbhome.file_records_under(
@@ -184,7 +195,7 @@ class ChessQLGames:
             NEWGAMES_FIELD_DEF,
             changed,
             self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE),
-            )
+        )
         if commit:
             self.dbhome.commit()
 
@@ -192,14 +203,15 @@ class ChessQLGames:
         self.set_recordset(games)
 
     def get_cql_statement_games(
-        self, query, sourceobject, initial_recordset=None, commit=True):
+        self, query, sourceobject, initial_recordset=None, commit=True
+    ):
         """Find game records matching ChessQL statement.
 
         query is detail extracted from query statement.
         sourceobject is previously calculated answer.  Set to None to force
         recalculation from query (after editing query statement usually).
         initial_recordset is games to which query is applied.
-        
+
         """
         if query is None:
             self.set_recordset(self.dbhome.recordlist_nil(self.dbset))
@@ -209,25 +221,30 @@ class ChessQLGames:
         # sourceobject is set to None if query must be recalculated.
         if sourceobject is not None:
             ppview = self.dbhome.recordlist_record_number(
-                PARTIAL_FILE_DEF,
-                key=sourceobject.key.recno)
+                PARTIAL_FILE_DEF, key=sourceobject.key.recno
+            )
             pprecalc = self.dbhome.recordlist_key(
                 PARTIAL_FILE_DEF,
                 NEWGAMES_FIELD_DEF,
-                key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE))
+                key=self.dbhome.encode_record_selector(NEWGAMES_FIELD_VALUE),
+            )
             pprecalc &= ppview
             if pprecalc.count_records() == 0:
                 ppcalc = self.dbhome.recordlist_key_startswith(
                     self.dbset,
                     PARTIALPOSITION_FIELD_DEF,
                     keystart=self.dbhome.encode_record_number(
-                        sourceobject.key.recno))
+                        sourceobject.key.recno
+                    ),
+                )
                 if ppcalc.count_records() != 0:
                     games = self.dbhome.recordlist_key(
                         self.dbset,
                         PARTIALPOSITION_FIELD_DEF,
                         key=self.dbhome.encode_record_number(
-                            sourceobject.key.recno))
+                            sourceobject.key.recno
+                        ),
+                    )
 
                     # Hand the list of games over to the user interface.
                     self.set_recordset(games)
@@ -242,11 +259,12 @@ class ChessQLGames:
             initial_recordlist |= initial_recordset
         games = self.get_games_matching_filters(
             query,
-            self.get_games_matching_parameters(query, initial_recordlist))
+            self.get_games_matching_parameters(query, initial_recordlist),
+        )
 
         # Hand the list of games over to the user interface.
         self.set_recordset(games)
-        
+
     # Not called anywhere.
     # Introduced at revision 3755 as part of 'on' filter implementation which
     # has been, at least temporarely, removed.
@@ -263,14 +281,16 @@ class ChessQLGames:
             for n in filter_.children:
                 if n.tokendef is Token.PIECE_DESIGNATOR:
                     pieces.intersection_update(
-                        self.pieces_matching_piece_designator(n))
+                        self.pieces_matching_piece_designator(n)
+                    )
                     if not pieces:
                         return pieces
             for n in filter_.children:
                 if self.is_filter_not_implemented(n):
                     continue
                 pieces.intersection_update(
-                    self.pieces_matching_filter(n, pieces))
+                    self.pieces_matching_filter(n, pieces)
+                )
                 if not pieces:
                     return pieces
             return pieces
@@ -283,15 +303,14 @@ class ChessQLGames:
                 # This cannot be correct given pieces initialisation, or
                 # more likely pieces initialisation is not correct too.
                 # However pieces_matching_filter is not called anywhere!
-                pieces.union(
-                    self.pieces_matching_filter(n, initialpieces))
+                pieces.union(self.pieces_matching_filter(n, initialpieces))
 
             return pieces
         else:
             if filter_.tokendef is Token.PIECE_DESIGNATOR:
                 return self.pieces_matching_piece_designator(filter_)
             return initialpieces
-        
+
     # Not called anywhere.
     # Introduced at revision 3755 as part of 'on' filter implementation which
     # has been, at least temporarely, removed.
@@ -308,14 +327,16 @@ class ChessQLGames:
             for n in filter_.children:
                 if n.tokendef is Token.PIECE_DESIGNATOR:
                     squares.intersection_update(
-                        self.squares_matching_piece_designator(n))
+                        self.squares_matching_piece_designator(n)
+                    )
                     if not squares:
                         return squares
             for n in filter_.children:
                 if self.is_filter_not_implemented(n):
                     continue
                 squares.intersection_update(
-                    self.squares_matching_filter(n, squares))
+                    self.squares_matching_filter(n, squares)
+                )
                 if not squares:
                     return squares
             return squares
@@ -328,25 +349,29 @@ class ChessQLGames:
                 # This cannot be correct given squares initialisation, or
                 # more likely squares initialisation is not correct too.
                 # However squares_matching_filter is not called anywhere!
-                squares.union(
-                    self.squares_matching_filter(n, initialsquares))
+                squares.union(self.squares_matching_filter(n, initialsquares))
 
             return squares
         else:
             if filter_.tokendef is Token.PIECE_DESIGNATOR:
                 return self.squares_matching_piece_designator(filter_)
             return initialsquares
-        
+
     def pieces_matching_piece_designator(self, filter_):
         """Return pieces matching a piece designator."""
 
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
-            raise ChessQLGamesError(''.join(("'",
-                                             Token.PIECE_DESIGNATOR.name,
-                                             "' expected but '",
-                                             str(filter_.name),
-                                             "'received",
-                                             )))
+            raise ChessQLGamesError(
+                "".join(
+                    (
+                        "'",
+                        Token.PIECE_DESIGNATOR.name,
+                        "' expected but '",
+                        str(filter_.name),
+                        "'received",
+                    )
+                )
+            )
         pieces = set()
         for ps in filter_.data.designator_set:
             p = ps[0]
@@ -357,17 +382,22 @@ class ChessQLGames:
             else:
                 pieces.add(p)
         return pieces
-        
+
     def squares_matching_piece_designator(self, filter_):
         """Return squares matching a piece designator."""
 
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
-            raise ChessQLGamesError(''.join(("'",
-                                             Token.PIECE_DESIGNATOR.name,
-                                             "' expected but '",
-                                             str(filter_.name),
-                                             "'received",
-                                             )))
+            raise ChessQLGamesError(
+                "".join(
+                    (
+                        "'",
+                        Token.PIECE_DESIGNATOR.name,
+                        "' expected but '",
+                        str(filter_.name),
+                        "'received",
+                    )
+                )
+            )
         squares = set()
         for ps in filter_.data.designator_set:
             if len(ps) == 1:
@@ -387,26 +417,32 @@ class ChessQLGames:
             self.not_implemented.add(filter_.tokendef.name)
             return True
         return False
-        
+
     def _games_matching_piece_designator(
-        self, filter_, datasource, movenumber, variation):
+        self, filter_, datasource, movenumber, variation
+    ):
         """Return games matching a piece designator."""
 
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
-            raise ChessQLGamesError(''.join(("'",
-                                             Token.PIECE_DESIGNATOR.name,
-                                             "' expected but '",
-                                             str(filter_.name),
-                                             "'received",
-                                             )))
+            raise ChessQLGamesError(
+                "".join(
+                    (
+                        "'",
+                        Token.PIECE_DESIGNATOR.name,
+                        "' expected but '",
+                        str(filter_.name),
+                        "'received",
+                    )
+                )
+            )
         answer = self._evaluate_piece_designator(
-            movenumber,
-            variation,
-            filter_.data.designator_set)
+            movenumber, variation, filter_.data.designator_set
+        )
         return datasource & answer
 
     def _games_matching_filter(
-        self, filter_, initialgames, movenumber, variation):
+        self, filter_, initialgames, movenumber, variation
+    ):
         """Return games matching filters in CQL statement.
 
         It is assumed FSNode.designator_set contains the expanded piece
@@ -419,14 +455,16 @@ class ChessQLGames:
             for n in filter_.children:
                 if n.tokendef is Token.PIECE_DESIGNATOR:
                     games &= self._games_matching_piece_designator(
-                        n, games, movenumber, variation)
+                        n, games, movenumber, variation
+                    )
                     if not games.count_records():
                         return games
             for n in filter_.children:
                 if self.is_filter_not_implemented(n):
                     continue
                 games &= self._games_matching_filter(
-                    n, games, movenumber, variation)
+                    n, games, movenumber, variation
+                )
                 if not games.count_records():
                     return games
             return games
@@ -436,32 +474,42 @@ class ChessQLGames:
                 if self.is_filter_not_implemented(n):
                     continue
                 e = self._games_matching_filter(
-                    n, initialgames, movenumber, variation)
+                    n, initialgames, movenumber, variation
+                )
                 games |= self._games_matching_filter(
-                    n, initialgames, movenumber, variation)
+                    n, initialgames, movenumber, variation
+                )
             return games
         else:
             if filter_.tokendef is Token.PIECE_DESIGNATOR:
                 return self._games_matching_piece_designator(
-                    filter_, initialgames, movenumber, variation)
+                    filter_, initialgames, movenumber, variation
+                )
             if filter_.tokendef is Token.RAY:
                 return self._games_matching_ray_filter(
-                    filter_, initialgames, movenumber, variation)
+                    filter_, initialgames, movenumber, variation
+                )
             games = self.dbhome.recordlist_nil(self.dbset)
             games |= initialgames
             return games
-        
+
     def _games_matching_ray_filter(
-        self, filter_, datasource, movenumber, variation):
+        self, filter_, datasource, movenumber, variation
+    ):
         """Return games matching a ray filter."""
 
         if filter_.tokendef is not Token.RAY:
-            raise ChessQLGamesError(''.join(("'",
-                                             Token.RAY.name,
-                                             "' expected but '",
-                                             str(filter_.name),
-                                             "'received",
-                                             )))
+            raise ChessQLGamesError(
+                "".join(
+                    (
+                        "'",
+                        Token.RAY.name,
+                        "' expected but '",
+                        str(filter_.name),
+                        "'received",
+                    )
+                )
+            )
         rf = RayFilter(filter_, movenumber, variation)
         rf.prune_end_squares(self.dbhome)
         rf.find_games_for_end_squares(self.cqlfinder)
@@ -474,7 +522,8 @@ class ChessQLGames:
         return recordset
 
     def _evaluate_piece_designator(
-        self, move_number, variation_code, piecesquares):
+        self, move_number, variation_code, piecesquares
+    ):
         """Return foundset calculated for piece designator using where class.
 
         The fieldname PieceSquareMove is now unavoidably a bit confusing, where
@@ -483,8 +532,11 @@ class ChessQLGames:
         meaning of move in this context.
 
         """
-        w = Where(where_eq_piece_designator(
-            move_number, variation_code, piecesquares))
+        w = Where(
+            where_eq_piece_designator(
+                move_number, variation_code, piecesquares
+            )
+        )
         w.lex()
         w.parse()
         v = w.validate(self.cqlfinder.db, self.cqlfinder.dbset)
@@ -507,7 +559,8 @@ class ChessQLGames:
         self.not_implemented = set()
         for movenumber in move_number_in_key_range(key):
             found |= self._games_matching_filter(
-                query.cql_filters, games, movenumber, '0')
+                query.cql_filters, games, movenumber, "0"
+            )
         return found
 
     # Version of get_games_matching_filters() to process CQL parameters.
@@ -522,8 +575,9 @@ class ChessQLGames:
         return found
 
     def _get_high_move_number(self):
-        cursor = self.dbhome.database_cursor(self.dbset,
-                                             PIECESQUAREMOVE_FIELD_DEF)
+        cursor = self.dbhome.database_cursor(
+            self.dbset, PIECESQUAREMOVE_FIELD_DEF
+        )
         try:
             return cursor.last()[0]
         except TypeError:
@@ -557,18 +611,22 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
             # Rules of chess imply whole piece designator finds all games if
             # any of 'A', 'a', 'K', 'k', and '_', are in designator set.
             if ps[0] in ALL_GAMES_MATCH_PIECE_DESIGNATORS:
-                return ' '.join(
-                    (pmfield, EQ, ''.join((mns, variation_code,
-                                           FEN_WHITE_KING))))
-            
-            pmds.add(''.join((mns, variation_code, ps[0])))
+                return " ".join(
+                    (
+                        pmfield,
+                        EQ,
+                        "".join((mns, variation_code, FEN_WHITE_KING)),
+                    )
+                )
+
+            pmds.add("".join((mns, variation_code, ps[0])))
             continue
         if ps[0] == EMPTY_SQUARE_NAME:
             sq = ps[1:]
 
             # 'not field eq value1 or value2' does not work, it should, but
             # 'not field eq value1 and not field eq value2' does work.
-            #emptyds.add(' '.join(
+            # emptyds.add(' '.join(
             #    (NOT,
             #     smfield,
             #     EQ,
@@ -576,46 +634,62 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
             #     OR,
             #     ''.join((mns, variation_code, sq + ANY_BLACK_PIECE_NAME)),
             #     )))
-            emptyds.add(' '.join(
-                (NOT,
-                 smfield,
-                 EQ,
-                 ''.join((mns, variation_code, sq + ANY_WHITE_PIECE_NAME)),
-                 AND,
-                 NOT,
-                 smfield,
-                 EQ,
-                 ''.join((mns, variation_code, sq + ANY_BLACK_PIECE_NAME)),
-                 )))
+            emptyds.add(
+                " ".join(
+                    (
+                        NOT,
+                        smfield,
+                        EQ,
+                        "".join(
+                            (mns, variation_code, sq + ANY_WHITE_PIECE_NAME)
+                        ),
+                        AND,
+                        NOT,
+                        smfield,
+                        EQ,
+                        "".join(
+                            (mns, variation_code, sq + ANY_BLACK_PIECE_NAME)
+                        ),
+                    )
+                )
+            )
 
             continue
         if ps[0] in anypiece:
-            smds.add(''.join(
-                (mns,
-                 variation_code,
-                 ps[1:] + ps[0],
-                 )))
+            smds.add(
+                "".join(
+                    (
+                        mns,
+                        variation_code,
+                        ps[1:] + ps[0],
+                    )
+                )
+            )
             continue
-        psmds.add(''.join(
-            (mns,
-             variation_code,
-             ps[1:] + ps[0],
-             )))
+        psmds.add(
+            "".join(
+                (
+                    mns,
+                    variation_code,
+                    ps[1:] + ps[0],
+                )
+            )
+        )
 
     phrases = []
     if psmds:
-        phrases.append(' '.join((psmfield, EQ, OR.join('  ').join(psmds))))
+        phrases.append(" ".join((psmfield, EQ, OR.join("  ").join(psmds))))
     if pmds:
-        phrases.append(' '.join((pmfield, EQ, OR.join('  ').join(pmds))))
+        phrases.append(" ".join((pmfield, EQ, OR.join("  ").join(pmds))))
     if smds:
-        phrases.append(' '.join((smfield, EQ, OR.join('  ').join(smds))))
+        phrases.append(" ".join((smfield, EQ, OR.join("  ").join(smds))))
     if emptyds:
-        phrases.append(OR.join('  ').join(emptyds))
+        phrases.append(OR.join("  ").join(emptyds))
     if phrases:
-        return OR.join('  ').join(phrases)
+        return OR.join("  ").join(phrases)
 
 
-#def move_number_str(move_number):
+# def move_number_str(move_number):
 #    """Return hex(move_number) values without leading '0x' but prefixed with
 #    string length.
 #    """
@@ -629,5 +703,5 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
 
 def move_number_in_key_range(key):
     """Yield the move number keys in a range one-by-one."""
-    for n in range(1, literal_eval('0x' + key[1:int(key[0]) + 1])):
+    for n in range(1, literal_eval("0x" + key[1 : int(key[0]) + 1])):
         yield n
