@@ -16,6 +16,5 @@ from .fullposition import FullPosition
 
 
 class FullPositionDS(FullPosition, DataSourceCursor):
-    
-    """Combine a standard DataSourceCursor with FullPosition.
-    """
+
+    """Combine a standard DataSourceCursor with FullPosition."""
