@@ -22,7 +22,7 @@ from pgn_read.core.constants import (
     TAG_DATE,
     TAG_WHITE,
     TAG_BLACK,
-    )
+)
 
 from .pgn import (
     GameDisplayMoves,
@@ -31,7 +31,7 @@ from .pgn import (
     GameRepertoireUpdate,
     GameTags,
     GameUpdate,
-    )
+)
 from .constants import (
     START_RAV,
     END_RAV,
@@ -43,7 +43,7 @@ from .constants import (
     HIDE_END_COMMENT,
     END_COMMENT,
     SPECIAL_TAG_DATE,
-    )
+)
 from .cqlstatement import CQLStatement
 from .filespec import (
     POSITIONS_FIELD_DEF,
@@ -60,7 +60,7 @@ from .filespec import (
     PARTIALPOSITION_NAME_FIELD_DEF,
     RULE_FIELD_DEF,
     COMMAND_FIELD_DEF,
-    )
+)
 from .analysis import Analysis
 from .querystatement import QueryStatement, re_normalize_player_name
 from .engine import Engine
@@ -73,9 +73,8 @@ class ChessRecordError(Exception):
 
 
 class ChessDBkeyGame(KeyData):
-    
-    """Primary key of chess game.
-    """
+
+    """Primary key of chess game."""
 
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
@@ -83,29 +82,27 @@ class ChessDBkeyGame(KeyData):
             return self.recno == other.recno
         except:
             return False
-    
+
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
         try:
             return self.recno != other.recno
         except:
             return True
-        
+
 
 class ChessDBvaluePGN(Value):
-    
-    """Methods common to all chess PGN data classes.
-    """
+
+    """Methods common to all chess PGN data classes."""
 
     def __init__(self):
         super().__init__()
         self.collected_game = None
-    
+
     @staticmethod
     def encode_move_number(key):
-        """Return base 256 string for integer with left-end most significant.
-        """
-        return key.to_bytes(2, byteorder='big')
+        """Return base 256 string for integer with left-end most significant."""
+        return key.to_bytes(2, byteorder="big")
 
     def load(self, value):
         """Get game from value."""
@@ -113,11 +110,11 @@ class ChessDBvaluePGN(Value):
 
     def pack_value(self):
         """Return PGN text for game."""
-        return repr(''.join(self.collected_game._text))
-        
+        return repr("".join(self.collected_game._text))
+
 
 class ChessDBvalueGame(PGN, ChessDBvaluePGN):
-    
+
     """Chess game data.
 
     Data is indexed by PGN Seven Tag Roster tags.
@@ -138,27 +135,29 @@ class ChessDBvalueGame(PGN, ChessDBvaluePGN):
 
                 # PGN specification states colon is used to separate player
                 # names in consultation games.
-                index[field] = [' '.join(re_normalize_player_name.findall(tf))
-                                for tf in tags[field].split(':')]
+                index[field] = [
+                    " ".join(re_normalize_player_name.findall(tf))
+                    for tf in tags[field].split(":")
+                ]
 
             elif field in SEVEN_TAG_ROSTER:
                 index[field] = [tags[field]]
         if TAG_DATE in tags:
             index[PGN_DATE_FIELD_DEF] = [
-                tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)]
+                tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)
+            ]
         return v
 
 
 class ChessDBrecordGame(Record):
-    
-    """Chess game record customised for displaying the game score and tags.
-    """
+
+    """Chess game record customised for displaying the game score and tags."""
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         super(ChessDBrecordGame, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvalueGame)
+            ChessDBkeyGame, ChessDBvalueGame
+        )
 
     def clone(self):
         """Return copy of ChessDBrecordGame instance.
@@ -167,7 +166,7 @@ class ChessDBrecordGame(Record):
         are handled by super(...).clone().  (Hope that DPT CR LF restrictions
         will be removed at which point the bound method attributes will not
         be needed.  Then ChessDBrecordGame.clone() can be deleted.)
-        
+
         """
         # are conditions for deleting this method in place?
         clone = super(ChessDBrecordGame, self).clone()
@@ -175,10 +174,9 @@ class ChessDBrecordGame(Record):
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant.
-        """
-        return int.from_bytes(skey, byteorder='big')
-        
+        """Return integer from base 256 string with left-end most significant."""
+        return int.from_bytes(skey, byteorder="big")
+
     def delete_record(self, database, dbset):
         """Delete record not allowed using ChessDBrecordGame class.
 
@@ -194,10 +192,10 @@ class ChessDBrecordGame(Record):
 
         """
         raise ChessRecordError
-        
+
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
-        
+
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
         except the positions are held in self.value.collected_game._tags.
@@ -205,20 +203,21 @@ class ChessDBrecordGame(Record):
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
         differ in the move number.
-        
+
         """
         dbname = datasource.dbname
         if dbname != POSITIONS_FIELD_DEF:
             if dbname == GAMES_FILE_DEF:
                 return [(self.key.recno, self.srvalue)]
             elif dbname in self.value.collected_game._tags:
-                return [(self.value.collected_game._tags[dbname],
-                         self.key.pack())]
+                return [
+                    (self.value.collected_game._tags[dbname], self.key.pack())
+                ]
             else:
                 return []
         if partial == None:
             return []
-        
+
         moves = self.value.moves
         gamekey = datasource.dbhome.encode_record_number(self.key.pack())
         rav = 0
@@ -240,7 +239,7 @@ class ChessDBrecordGame(Record):
                     keys.append(convert_format(record, gamekey))
             ref += 1
         return keys
-        
+
     def put_record(self, database, dbset):
         """Put record not allowed using ChessDBrecordGame class.
 
@@ -251,9 +250,9 @@ class ChessDBrecordGame(Record):
 
 
 class ChessDBrecordGameText(Record):
-    
+
     """Chess game record customised for processing the game score as text.
-    
+
     Used to export games or repertoires from a database in the 'Import Format',
     see PGN specification 3.1, used to store the games.
 
@@ -261,9 +260,7 @@ class ChessDBrecordGameText(Record):
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
-        super(ChessDBrecordGameText, self).__init__(
-            ChessDBkeyGame,
-            ValueText)
+        super(ChessDBrecordGameText, self).__init__(ChessDBkeyGame, ValueText)
 
     def clone(self):
         """Return copy of ChessDBrecordGameText instance.
@@ -272,7 +269,7 @@ class ChessDBrecordGameText(Record):
         are handled by super(...).clone().  (Hope that DPT CR LF restrictions
         will be removed at which point the bound method attributes will not
         be needed.  Then ChessDBrecordGameText.clone() can be deleted.)
-        
+
         """
         # are conditions for deleting this method in place?
         clone = super(ChessDBrecordGameText, self).clone()
@@ -280,10 +277,9 @@ class ChessDBrecordGameText(Record):
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant.
-        """
-        return int.from_bytes(skey, byteorder='big')
-        
+        """Return integer from base 256 string with left-end most significant."""
+        return int.from_bytes(skey, byteorder="big")
+
     def delete_record(self, database, dbset):
         """Delete record not allowed using ChessDBrecordGameText class.
 
@@ -299,7 +295,7 @@ class ChessDBrecordGameText(Record):
 
         """
         raise ChessRecordError
-        
+
     def put_record(self, database, dbset):
         """Put record not allowed using ChessDBrecordGameText class.
 
@@ -310,9 +306,8 @@ class ChessDBrecordGameText(Record):
 
 
 class ChessDBvalueGameTags(ChessDBvalueGame):
-    
-    """Chess game data excluding PGN movetext but including PGN Tags.
-    """
+
+    """Chess game data excluding PGN movetext but including PGN Tags."""
 
     def __init__(self):
         """Extend with game source and move number encoder placeholders."""
@@ -326,7 +321,7 @@ class ChessDBvalueGameTags(ChessDBvalueGame):
         """
         return self.collected_game._tags.get(fieldname, None)
 
-    #def get_field_values(self, fieldname):
+    # def get_field_values(self, fieldname):
     #    """Return tuple of field values for fieldname.
 
     #    Added to support Find and Where classes.
@@ -351,38 +346,38 @@ class ChessDBvalueGameTags(ChessDBvalueGame):
         try:
             super().load(value)
         except StopIteration:
-            self.collected_game = next(self.read_games(
-                '{'+literal_eval(value)+'}*'))
+            self.collected_game = next(
+                self.read_games("{" + literal_eval(value) + "}*")
+            )
 
 
 class ChessDBrecordGameTags(Record):
-    
-    """Chess game record customised for displaying tag information for a game.
-    """
+
+    """Chess game record customised for displaying tag information for a game."""
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         super(ChessDBrecordGameTags, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvalueGameTags)
+            ChessDBkeyGame, ChessDBvalueGameTags
+        )
 
 
 class ChessDBrecordGamePosition(Record):
-    
+
     """Chess game record customised for displaying the game score only.
-    
+
     Much of the game structure to be represented in the row display is held
     in the Tkinter.Text object created for display.  Thus the processing of
     the record data is delegated to a PositionScore instance created when
     filling the grid.
-    
+
     """
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         super(ChessDBrecordGamePosition, self).__init__(
-            ChessDBkeyGame,
-            ValueText)
+            ChessDBkeyGame, ValueText
+        )
 
     def clone(self):
         """Return copy of ChessDBrecordGamePosition instance.
@@ -391,7 +386,7 @@ class ChessDBrecordGamePosition(Record):
         are handled by super(...).clone().  (Hope that DPT CR LF restrictions
         will be removed at which point the bound method attributes will not
         be needed.  Then ChessDBrecordGamePosition.clone() can be deleted.)
-        
+
         """
         # are conditions for deleting this method in place?
         clone = super(ChessDBrecordGamePosition, self).clone()
@@ -399,10 +394,9 @@ class ChessDBrecordGamePosition(Record):
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant.
-        """
-        return int.from_bytes(skey, byteorder='big')
-        
+        """Return integer from base 256 string with left-end most significant."""
+        return int.from_bytes(skey, byteorder="big")
+
     def delete_record(self, database, dbset):
         """Delete record not allowed using ChessDBrecordGamePosition class.
 
@@ -418,7 +412,7 @@ class ChessDBrecordGamePosition(Record):
 
         """
         raise ChessRecordError
-        
+
     def put_record(self, database, dbset):
         """Put record not allowed using ChessDBrecordGamePosition class.
 
@@ -443,10 +437,11 @@ class _GameUpdate(GameUpdate):
     not terminate the wrapping comment.
 
     """
+
     def pgn_error_notification(self):
         """Insert error '{' before movetext token which causes PGN error."""
         if self._movetext_offset is not None:
-            self._text.append(START_COMMENT+ERROR_START_COMMENT)
+            self._text.append(START_COMMENT + ERROR_START_COMMENT)
 
     def pgn_error_recovery(self):
         """Insert error '}' before token which ends the scope of a PGN error.
@@ -455,7 +450,7 @@ class _GameUpdate(GameUpdate):
 
         """
         if self._movetext_offset is not None:
-            self._text.append(ESCAPE_END_COMMENT+END_COMMENT)
+            self._text.append(ESCAPE_END_COMMENT + END_COMMENT)
 
     def pgn_mark_comment_in_error(self, comment):
         """Return comment with '}' replaced by a presumed unlikely sequence.
@@ -463,15 +458,15 @@ class _GameUpdate(GameUpdate):
         One possibility is to wrap the error in a '{...}' comment.  The '}'
         token in any wrapped commment would end the comment wrapping the error
         prematurely, so replace with HIDE_END_COMMENT.
-        
+
         """
         return comment.replace(END_COMMENT, HIDE_END_COMMENT)
 
 
 class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
-    
+
     """Chess game data with position, piece location, and PGN Tag, indexes."""
-    
+
     # Replaces ChessDBvaluePGNUpdate and ChessDBvalueGameImport which had been
     # identical for a considerable time.
     # Decided that PGNUpdate should remain in pgn.core.parser because that code
@@ -505,8 +500,9 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
                     # names in consultation games.
                     try:
                         index[field] = [
-                            ' '.join(re_normalize_player_name.findall(tf))
-                            for tf in tags[field].split(':')]
+                            " ".join(re_normalize_player_name.findall(tf))
+                            for tf in tags[field].split(":")
+                        ]
                     except KeyError:
                         if field in tags:
                             raise
@@ -523,7 +519,8 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
             index[SQUAREMOVE_FIELD_DEF] = cg.squaremovekeys
             try:
                 index[PGN_DATE_FIELD_DEF] = [
-                    tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)]
+                    tags[TAG_DATE].replace(*SPECIAL_TAG_DATE)
+                ]
             except KeyError:
                 if TAG_DATE in tags:
                     raise
@@ -550,12 +547,13 @@ class ChessDBvaluePGNUpdate(PGN, ChessDBvaluePGN):
     # of the record instance.
     def is_error_comment_present(self):
         """Return True if an {Error: ...} comment is in the PGN text."""
-        return START_COMMENT + ERROR_START_COMMENT in ''.join(
-            self.collected_game._text)
-    
+        return START_COMMENT + ERROR_START_COMMENT in "".join(
+            self.collected_game._text
+        )
+
 
 class ChessDBrecordGameUpdate(Record):
-    
+
     """Chess game record customized for editing database records.
 
     Used to edit or insert a single record by typing in a widget.
@@ -565,8 +563,8 @@ class ChessDBrecordGameUpdate(Record):
     def __init__(self):
         """Extend with move number encode and decode methods"""
         super(ChessDBrecordGameUpdate, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvaluePGNUpdate)
+            ChessDBkeyGame, ChessDBvaluePGNUpdate
+        )
 
     def clone(self):
         """Return copy of ChessDBrecordGameUpdate instance.
@@ -575,7 +573,7 @@ class ChessDBrecordGameUpdate(Record):
         are handled by super(...).clone().  (Hope that DPT CR LF restrictions
         will be removed at which point the bound method attributes will not
         be needed.  Then ChessDBrecordGameUpdate.clone() can be deleted.)
-        
+
         """
         # are conditions for deleting this method in place?
         clone = super(ChessDBrecordGameUpdate, self).clone()
@@ -583,13 +581,12 @@ class ChessDBrecordGameUpdate(Record):
 
     @staticmethod
     def decode_move_number(skey):
-        """Return integer from base 256 string with left-end most significant.
-        """
-        return int.from_bytes(skey, byteorder='big')
-        
+        """Return integer from base 256 string with left-end most significant."""
+        return int.from_bytes(skey, byteorder="big")
+
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
-        
+
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
         except the positions are held in self.value.collected_game._tags.
@@ -597,20 +594,21 @@ class ChessDBrecordGameUpdate(Record):
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
         differ in the move number.
-        
+
         """
         dbname = datasource.dbname
         if dbname != POSITIONS_FIELD_DEF:
             if dbname == GAMES_FILE_DEF:
                 return [(self.key.recno, self.srvalue)]
             elif dbname in self.value.collected_game._tags:
-                return [(self.value.collected_game._tags[dbname],
-                         self.key.pack())]
+                return [
+                    (self.value.collected_game._tags[dbname], self.key.pack())
+                ]
             else:
                 return []
         if partial == None:
             return []
-        
+
         moves = self.value.moves
         gamekey = datasource.dbhome.encode_record_number(self.key.pack())
         rav = 0
@@ -632,27 +630,28 @@ class ChessDBrecordGameUpdate(Record):
                     keys.append(convert_format(record, gamekey))
             ref += 1
         return keys
-        
+
     def load_instance(self, database, dbset, dbname, record):
         """Extend to set source for game if necessary."""
         super(ChessDBrecordGameUpdate, self).load_instance(
-            database, dbset, dbname, record)
-    
+            database, dbset, dbname, record
+        )
+
         # Never called because attribute is not bound anywhere and no
         # exceptions are seen ever.
         # Until ..tools.chesstab-4-1-1_castling-option-correction written, and
         # following code commented.  I assume the idea made sense once!
         # Might as well let superclass method be used directly.
-        #if self.value.callbacktried:
+        # if self.value.callbacktried:
         #    pass
-        #elif self.value.callbacktried == None:
+        # elif self.value.callbacktried == None:
         #    pass
-        #elif not self.value.callbacktried:
+        # elif not self.value.callbacktried:
         #    self.value.set_game_source(record[0])
-    
+
 
 class ChessDBrecordGameImport(Record):
-    
+
     """Chess game record customised for importing games from PGN files.
 
     Used to import multiple records from a PGN file.
@@ -662,22 +661,23 @@ class ChessDBrecordGameImport(Record):
     def __init__(self):
         """Customise Record with chess database import key and value classes"""
         super(ChessDBrecordGameImport, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvaluePGNUpdate)
+            ChessDBkeyGame, ChessDBvaluePGNUpdate
+        )
 
     def import_pgn(self, database, source, sourcename, reporter=None):
         """Update database with games read from source."""
         self.set_database(database)
-        #self.value.set_game_source(sourcename)
+        # self.value.set_game_source(sourcename)
         if reporter is not None:
-            reporter('Extracting games from ' + sourcename)
+            reporter("Extracting games from " + sourcename)
         ddup = database.deferred_update_points
         db_segment_size = SegmentSize.db_segment_size
         value = self.value
         count = 0
         for collected_game in value.read_games(source):
             value.set_game_source(
-                sourcename if not collected_game.is_pgn_valid() else None)
+                sourcename if not collected_game.is_pgn_valid() else None
+            )
             self.key.recno = None
             value.collected_game = collected_game
             self.put_record(self.database, GAMES_FILE_DEF)
@@ -686,28 +686,32 @@ class ChessDBrecordGameImport(Record):
                     base = self.key.recno - self.key.recno % db_segment_size
                 count += 1
                 if self.key.recno % db_segment_size in ddup:
-                    reporter(' '.join(('Game',
-                                       str(count),
-                                       'stored as record',
-                                       str(self.key.recno),
-                                       'offset',
-                                       str(self.key.recno - base))))
+                    reporter(
+                        " ".join(
+                            (
+                                "Game",
+                                str(count),
+                                "stored as record",
+                                str(self.key.recno),
+                                "offset",
+                                str(self.key.recno - base),
+                            )
+                        )
+                    )
                     database.deferred_update_housekeeping()
         if reporter is not None:
-            reporter('Extraction from ' + sourcename + ' done')
-            reporter('', timestamp=False)
+            reporter("Extraction from " + sourcename + " done")
+            reporter("", timestamp=False)
 
 
 class ChessDBkeyPartial(KeyData):
-    
-    """Primary key of partial position record.
-    """
+
+    """Primary key of partial position record."""
 
 
 class ChessDBvaluePartial(CQLStatement, Value):
-    
-    """Partial position data.
-    """
+
+    """Partial position data."""
 
     def __init__(self):
         super(ChessDBvaluePartial, self).__init__()
@@ -715,8 +719,10 @@ class ChessDBvaluePartial(CQLStatement, Value):
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
         try:
-            if (self.get_name_statement_text() !=
-                other.get_name_statement_text()):
+            if (
+                self.get_name_statement_text()
+                != other.get_name_statement_text()
+            ):
                 return False
             else:
                 return True
@@ -726,14 +732,16 @@ class ChessDBvaluePartial(CQLStatement, Value):
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
         try:
-            if (self.get_name_statement_text() ==
-                other.get_name_statement_text()):
+            if (
+                self.get_name_statement_text()
+                == other.get_name_statement_text()
+            ):
                 return False
             else:
                 return True
         except:
             return True
-    
+
     def load(self, value):
         """Set partial position from value"""
         self.process_statement(literal_eval(value))
@@ -748,25 +756,24 @@ class ChessDBvaluePartial(CQLStatement, Value):
         index = v[1]
         index[PARTIALPOSITION_NAME_FIELD_DEF] = [self.get_name_text()]
         return v
-        
+
 
 class ChessDBrecordPartial(Record):
-    
-    """Partial position record.
-    """
+
+    """Partial position record."""
 
     def __init__(self):
         """Extend as a partial position record."""
         super(ChessDBrecordPartial, self).__init__(
-            ChessDBkeyPartial,
-            ChessDBvaluePartial)
-        
+            ChessDBkeyPartial, ChessDBvaluePartial
+        )
+
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
-        
+
         The partial position name is held in an attribute which is not named
         for the field where it exists in the database.
-        
+
         """
         if datasource.dbname == PARTIALPOSITION_NAME_FIELD_DEF:
             return [(self.value.get_name_text(), self.key.pack())]
@@ -783,13 +790,12 @@ class ChessDBrecordPartial(Record):
         self.value.set_database(self.database)
         self.value.dbset = GAMES_FILE_DEF
         super().load_value(value)
-        
+
 
 # Not quite sure what customization needed yet
 class ChessDBvalueRepertoire(PGN, Value):
-    
-    """Repertoire data using custom non-standard tags in PGN format.
-    """
+
+    """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self, game_class=GameRepertoireDisplayMoves):
         """Extend with game source and move number encoder placeholders."""
@@ -803,9 +809,8 @@ class ChessDBvalueRepertoire(PGN, Value):
 
 # Not quite sure what customization needed yet
 class ChessDBvalueRepertoireTags(ChessDBvalueRepertoire):
-    
-    """Repertoire data using custom non-standard tags in PGN format.
-    """
+
+    """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self):
         """Extend with game source and move number encoder placeholders."""
@@ -814,9 +819,8 @@ class ChessDBvalueRepertoireTags(ChessDBvalueRepertoire):
 
 # Not quite sure what customization needed yet
 class ChessDBvalueRepertoireUpdate(PGN, ChessDBvaluePGN):
-    
-    """Repertoire data using custom non-standard tags in PGN format.
-    """
+
+    """Repertoire data using custom non-standard tags in PGN format."""
 
     def __init__(self):
         """Extend with game source and move number encoder placeholders."""
@@ -843,48 +847,45 @@ class ChessDBvalueRepertoireUpdate(PGN, ChessDBvaluePGN):
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoire(ChessDBrecordGame):
-    
-    """Repertoire record customised for exporting repertoire information.
-    """
+
+    """Repertoire record customised for exporting repertoire information."""
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         # Skip the immediate superclass __init__ to fix key and value classes
         super(ChessDBrecordGame, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvalueRepertoire)
+            ChessDBkeyGame, ChessDBvalueRepertoire
+        )
 
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoireTags(ChessDBrecordGameTags):
-    
-    """Repertoire record customised for displaying repertoire tag information.
-    """
+
+    """Repertoire record customised for displaying repertoire tag information."""
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         # Skip the immediate superclass __init__ to fix key and value classes
         super(ChessDBrecordGameTags, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvalueRepertoireTags)
-    
+            ChessDBkeyGame, ChessDBvalueRepertoireTags
+        )
+
 
 # Not quite sure what customization needed yet
 class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
-    
-    """Repertoire record customized for editing repertoire records.
-    """
+
+    """Repertoire record customized for editing repertoire records."""
 
     def __init__(self):
         """Extend with move number encode and decode methods"""
         # Skip the immediate superclass __init__ to fix key and value classes
         super(ChessDBrecordGameUpdate, self).__init__(
-            ChessDBkeyGame,
-            ChessDBvalueRepertoireUpdate)
-        
+            ChessDBkeyGame, ChessDBvalueRepertoireUpdate
+        )
+
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
-        
+
         The keys for the secondary databases in a ChessDatabase instance are
         embedded in, or derived from, the PGN string for the game.  All
         except the positions are held in self.value.collected_game._tags.
@@ -892,7 +893,7 @@ class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
         position are of interest.  The partial argument is used to select
         the relevant keys.  The position is in partial and the keys will
         differ in the move number.
-        
+
         """
         dbname = datasource.dbname
         if dbname == REPERTOIRE_FILE_DEF:
@@ -901,15 +902,14 @@ class ChessDBrecordRepertoireUpdate(ChessDBrecordGameUpdate):
             return [(self.value.collected_game._tags[dbname], self.key.pack())]
         else:
             return []
-        
+
 
 class ChessDBvalueAnalysis(Analysis, Value):
-    
-    """Chess engine analysis data for a position.
-    """
+
+    """Chess engine analysis data for a position."""
 
     def __init__(self):
-        """"""
+        """ """
         super().__init__()
 
     def pack(self):
@@ -922,13 +922,13 @@ class ChessDBvalueAnalysis(Analysis, Value):
 
 
 class ChessDBrecordAnalysis(Record):
-    
+
     """Chess game record customised for chess engine analysis data.
 
     No index values are derived from PGN move text, so there is no advantage in
     separate classes for display and update.  The PGN FEN tag provides the only
     PGN related index value used.
-    
+
     """
 
     def __init__(self):
@@ -937,15 +937,13 @@ class ChessDBrecordAnalysis(Record):
 
 
 class ChessDBkeyQuery(KeyData):
-    
-    """Primary key of game selection rule record.
-    """
+
+    """Primary key of game selection rule record."""
 
 
 class ChessDBvalueQuery(QueryStatement, Value):
-    
-    """Game selection rule data.
-    """
+
+    """Game selection rule data."""
 
     def __init__(self):
         super(ChessDBvalueQuery, self).__init__()
@@ -953,8 +951,10 @@ class ChessDBvalueQuery(QueryStatement, Value):
     def __eq__(self, other):
         """Return (self == other).  Attributes are compared explicitly."""
         try:
-            if (self.get_name_query_statement_text() !=
-                other.get_name_query_statement_text()):
+            if (
+                self.get_name_query_statement_text()
+                != other.get_name_query_statement_text()
+            ):
                 return False
             else:
                 return True
@@ -964,14 +964,16 @@ class ChessDBvalueQuery(QueryStatement, Value):
     def __ne__(self, other):
         """Return (self != other).  Attributes are compared explicitly."""
         try:
-            if (self.get_name_query_statement_text() ==
-                other.get_name_query_statement_text()):
+            if (
+                self.get_name_query_statement_text()
+                == other.get_name_query_statement_text()
+            ):
                 return False
             else:
                 return True
         except:
             return True
-    
+
     def load(self, value):
         """Set game selection rule from value"""
         self.process_query_statement(literal_eval(value))
@@ -986,25 +988,24 @@ class ChessDBvalueQuery(QueryStatement, Value):
         index = v[1]
         index[RULE_FIELD_DEF] = [self.get_name_text()]
         return v
-        
+
 
 class ChessDBrecordQuery(Record):
-    
-    """Game selection rule record.
-    """
+
+    """Game selection rule record."""
 
     def __init__(self):
         """Extend as a game selection rule record."""
         super(ChessDBrecordQuery, self).__init__(
-            ChessDBkeyQuery,
-            ChessDBvalueQuery)
-        
+            ChessDBkeyQuery, ChessDBvalueQuery
+        )
+
     def get_keys(self, datasource=None, partial=None):
         """Return list of (key, value) tuples.
-        
+
         The game selection rule name is held in an attribute which is not named
         for the field where it exists in the database.
-        
+
         """
         if datasource.dbname == RULE_FIELD_DEF:
             return [(self.value.get_name_text(), self.key.pack())]
@@ -1024,15 +1025,13 @@ class ChessDBrecordQuery(Record):
 
 
 class ChessDBkeyEngine(KeyData):
-    
-    """Primary key of chess engine record.
-    """
+
+    """Primary key of chess engine record."""
 
 
 class ChessDBvalueEngine(Engine, Value):
-    
-    """Game selection rule data.
-    """
+
+    """Game selection rule data."""
 
     def __init__(self):
         super(ChessDBvalueEngine, self).__init__()
@@ -1043,15 +1042,14 @@ class ChessDBvalueEngine(Engine, Value):
         index = v[1]
         index[COMMAND_FIELD_DEF] = [self.get_name_text()]
         return v
-        
+
 
 class ChessDBrecordEngine(Record):
-    
-    """Chess engine record.
-    """
+
+    """Chess engine record."""
 
     def __init__(self):
         """Extend as a game selection rule record."""
         super(ChessDBrecordEngine, self).__init__(
-            ChessDBkeyEngine,
-            ChessDBvalueEngine)
+            ChessDBkeyEngine, ChessDBvalueEngine
+        )
