@@ -44,14 +44,14 @@ from pgn_read.core.constants import (
     FEN_WHITE_ACTIVE,
     FEN_BLACK_ACTIVE,
     PGN_CAPTURE_MOVE,
-    )
+)
 from pgn_read.core.parser import add_token_to_game
 
 from .pgn import GameMove
 from .constants import (
     NOPIECE,
     FEN_CONTEXT,
-    )
+)
 
 _PIECE_TO_PGN = {
     FEN_WHITE_KING: PGN_KING,
@@ -66,96 +66,117 @@ _PIECE_TO_PGN = {
     FEN_BLACK_BISHOP: PGN_BISHOP,
     FEN_BLACK_KNIGHT: PGN_KNIGHT,
     FEN_BLACK_PAWN: PGN_PAWN,
-    }
+}
 _PROMOTE = {
-    PGN_QUEEN.lower(): ''.join(('=', PGN_QUEEN)),
-    PGN_ROOK.lower(): ''.join(('=', PGN_ROOK)),
-    PGN_BISHOP.lower(): ''.join(('=', PGN_BISHOP)),
-    PGN_KNIGHT.lower(): ''.join(('=', PGN_KNIGHT)),
-    '': '',
-    }
-_CASTLES = {'e1g1': 'O-O', 'e8g8': 'O-O', 'e1c1': 'O-O-O', 'e8c8': 'O-O-O'}
+    PGN_QUEEN.lower(): "".join(("=", PGN_QUEEN)),
+    PGN_ROOK.lower(): "".join(("=", PGN_ROOK)),
+    PGN_BISHOP.lower(): "".join(("=", PGN_BISHOP)),
+    PGN_KNIGHT.lower(): "".join(("=", PGN_KNIGHT)),
+    "": "",
+}
+_CASTLES = {"e1g1": "O-O", "e8g8": "O-O", "e1c1": "O-O-O", "e8c8": "O-O-O"}
 _CASTLEKEY = {
-    'e1g1': FEN_WHITE_KING,
-    'e8g8': FEN_BLACK_KING,
-    'e1c1': FEN_WHITE_KING,
-    'e8c8': FEN_BLACK_KING}
+    "e1g1": FEN_WHITE_KING,
+    "e8g8": FEN_BLACK_KING,
+    "e1c1": FEN_WHITE_KING,
+    "e8c8": FEN_BLACK_KING,
+}
 _ACTIVE_PIECES = {
-    FEN_WHITE_ACTIVE: FEN_WHITE_PIECES, FEN_BLACK_ACTIVE: FEN_BLACK_PIECES}
+    FEN_WHITE_ACTIVE: FEN_WHITE_PIECES,
+    FEN_BLACK_ACTIVE: FEN_BLACK_PIECES,
+}
 
-re_move = re.compile(''.join(('^',
-                              '([a-h][1-8])',
-                              '([a-h][1-8])',
-                              '([qrbn]?)',
-                              '$')))
+re_move = re.compile(
+    "".join(("^", "([a-h][1-8])", "([a-h][1-8])", "([qrbn]?)", "$"))
+)
 
 
 def generate_pgn_for_uci_moves_in_position(moves, fen):
-    """Return PGN-style movetext and update position for unambiguous moves.
-
-    """
+    """Return PGN-style movetext and update position for unambiguous moves."""
     game = GameMove()
     piece_placement_data = game._piece_placement_data
     text = []
     try:
         moves = moves.split()
     except:
-        return ''.join(
-            ("{'",
-             str(moves),
-             "' cannot be a move, 'Yz0' inserted.}Yz0"))
+        return "".join(
+            ("{'", str(moves), "' cannot be a move, 'Yz0' inserted.}Yz0")
+        )
     if not moves:
         return "{'' is not a move, 'Yz0' inserted. Rest '' ignored.}Yz0"
     tagtext = fen.join(FEN_CONTEXT)
     match_end = add_token_to_game(tagtext, game)
     match_end = add_token_to_game(tagtext, game, pos=match_end)
     if not game.set_initial_position():
-        return ''.join((
-            "{'Forsyth-Edwards Notation sets an illegal position. ",
-            "Move 'Yz0' inserted.}Yz0"))
+        return "".join(
+            (
+                "{'Forsyth-Edwards Notation sets an illegal position. ",
+                "Move 'Yz0' inserted.}Yz0",
+            )
+        )
     for count, move in enumerate(moves):
         g = re_move.match(move)
         if not g:
-            text.append(''.join(
-                ("{'",
-                 str(move),
-                 "' cannot be a move, 'Yz0' inserted. Rest '",
-                 ' '.join(moves[count+1:]),
-                 "' ignored.}Yz0")))
+            text.append(
+                "".join(
+                    (
+                        "{'",
+                        str(move),
+                        "' cannot be a move, 'Yz0' inserted. Rest '",
+                        " ".join(moves[count + 1 :]),
+                        "' ignored.}Yz0",
+                    )
+                )
+            )
             break
         from_square, to_square, promote_to = g.groups()
 
         # from_square must contain a piece belonging to side with the move.
         if from_square not in piece_placement_data:
-            text.append(''.join(
-                ("{'",
-                 str(move),
-                 "' does not refer to a piece of the active side, ",
-                 "'Yz0' inserted. Rest '",
-                 ' '.join(moves[count+1:]),
-                 "' ignored.}Yz0")))
+            text.append(
+                "".join(
+                    (
+                        "{'",
+                        str(move),
+                        "' does not refer to a piece of the active side, ",
+                        "'Yz0' inserted. Rest '",
+                        " ".join(moves[count + 1 :]),
+                        "' ignored.}Yz0",
+                    )
+                )
+            )
             break
         piece = piece_placement_data[from_square].name
         if piece not in _ACTIVE_PIECES[game._active_color]:
-            text.append(''.join(
-                ("{'",
-                 str(move),
-                 "' does not refer to a piece of the active side, ",
-                 "'Yz0' inserted. Rest '",
-                 ' '.join(moves[count+1:]),
-                 "' ignored.}Yz0")))
+            text.append(
+                "".join(
+                    (
+                        "{'",
+                        str(move),
+                        "' does not refer to a piece of the active side, ",
+                        "'Yz0' inserted. Rest '",
+                        " ".join(moves[count + 1 :]),
+                        "' ignored.}Yz0",
+                    )
+                )
+            )
             break
 
         # to_square must not contain a piece belonging to side with the move.
         if to_square in piece_placement_data:
             destination_piece = piece_placement_data[to_square].name
             if destination_piece in _ACTIVE_PIECES[game._active_color]:
-                text.append(''.join(
-                    ("{'",
-                     str(move),
-                     "' cannot be a move, 'Yz0' inserted. Rest '",
-                     ' '.join(moves[count+1:]),
-                     "' ignored.}Yz0")))
+                text.append(
+                    "".join(
+                        (
+                            "{'",
+                            str(move),
+                            "' cannot be a move, 'Yz0' inserted. Rest '",
+                            " ".join(moves[count + 1 :]),
+                            "' ignored.}Yz0",
+                        )
+                    )
+                )
                 break
 
         # Maybe the _PIECE_TO_PGN mapping should be replaced by an attribute
@@ -168,8 +189,9 @@ def generate_pgn_for_uci_moves_in_position(moves, fen):
         # constructed PGN move happens to be legal.
 
         # Castles is treated as a king move of two squares, otherwise illegal.
-        if (move in _CASTLES and
-            piece_placement_data[from_square].name == _CASTLEKEY.get(move)):
+        if move in _CASTLES and piece_placement_data[
+            from_square
+        ].name == _CASTLEKEY.get(move):
             pgn_movetext = _CASTLES[move]
 
         # Pawn moves are given in a mixture of short algebraic notation and
@@ -190,33 +212,34 @@ def generate_pgn_for_uci_moves_in_position(moves, fen):
                 else:
                     pgn_movetext = from_square + to_square
             else:
-                pgn_movetext = ''.join(
-                    (from_square[0], PGN_CAPTURE_MOVE, to_square, promote_to))
+                pgn_movetext = "".join(
+                    (from_square[0], PGN_CAPTURE_MOVE, to_square, promote_to)
+                )
 
             # Pawn must not be promoted to ranks othen than 1 or 8.
             if promote_to:
-                if to_square[1] not in '18':
-                    text.append(''.join(
-                        ("{'",
-                         str(move),
-                         "' cannot be a move, 'Yz0' inserted. Rest '",
-                         ' '.join(moves[count+1:]),
-                         "' ignored.}Yz0")))
+                if to_square[1] not in "18":
+                    text.append(
+                        "".join(
+                            (
+                                "{'",
+                                str(move),
+                                "' cannot be a move, 'Yz0' inserted. Rest '",
+                                " ".join(moves[count + 1 :]),
+                                "' ignored.}Yz0",
+                            )
+                        )
+                    )
                     break
-        
+
         # Piece moves are given in long algebraic notation, relying on the
         # GameMove class to produce short algebraic notation if possible.
         elif to_square not in piece_placement_data:
-            pgn_movetext = ''.join(
-                (piece,
-                 from_square,
-                 to_square))
+            pgn_movetext = "".join((piece, from_square, to_square))
         else:
-            pgn_movetext = ''.join(
-                (piece,
-                 from_square,
-                 PGN_CAPTURE_MOVE,
-                 to_square))
+            pgn_movetext = "".join(
+                (piece, from_square, PGN_CAPTURE_MOVE, to_square)
+            )
 
         # Generally the 'if matchend ...' should be 'while matchend ...', but
         # pgn_movetext is a single move so two calls to add_token_to_game are
@@ -228,12 +251,17 @@ def generate_pgn_for_uci_moves_in_position(moves, fen):
             add_token_to_game(pgn_movetext, game, pos=matchend)
 
         if game.state is not None:
-            text.append(''.join(
-                ("{'",
-                 str(move),
-                 "' cannot be a move, 'Yz0' inserted. Rest '",
-                 ' '.join(moves[count+1:]),
-                 "' ignored.}Yz0")))
+            text.append(
+                "".join(
+                    (
+                        "{'",
+                        str(move),
+                        "' cannot be a move, 'Yz0' inserted. Rest '",
+                        " ".join(moves[count + 1 :]),
+                        "' ignored.}Yz0",
+                    )
+                )
+            )
             break
         text.append(game._text[-1])
-    return ' '.join(text)
+    return " ".join(text)
