@@ -13,7 +13,7 @@ from ..core.engine import Engine
 from .eventspec import EventSpec
 from .blanktext import NonTagBind, BlankText
 from .sharedtext import SharedTextEngineText
-    
+
 
 class EngineText(SharedTextEngineText, BlankText):
 
@@ -35,16 +35,12 @@ class EngineText(SharedTextEngineText, BlankText):
     Attribute _most_recent_bindings is set to indicate the initial set of
     event bindings.  Instances will override this as required.
 
-    
+
     """
 
     def __init__(
-        self,
-        panel,
-        ui=None,
-        items_manager=None,
-        itemgrid=None,
-        **ka):
+        self, panel, ui=None, items_manager=None, itemgrid=None, **ka
+    ):
         """Create widgets to display chess engine definition."""
         super().__init__(panel, items_manager=items_manager, **ka)
         self.ui = ui
@@ -54,39 +50,40 @@ class EngineText(SharedTextEngineText, BlankText):
 
         # Selection rule parser instance to process text.
         self.definition = Engine()
-        
+
     # Engine description records are always shown in a Toplevel.
     # Dismiss item and database update actions by keypress and buttunpress
     # are assumed to be exposed by the associated solentware_misc class.
     def get_primary_activity_events(self):
-        return (
-            (EventSpec.databaseenginedisplay_run, self.run_engine),
-            )
+        return ((EventSpec.databaseenginedisplay_run, self.run_engine),)
 
     def set_primary_activity_bindings(self, switch=True):
         """Switch bindings for editing chess engine definition on or off."""
         self.set_event_bindings_score(
-            self.get_primary_activity_events(),
-            switch=switch)
+            self.get_primary_activity_events(), switch=switch
+        )
         self.set_event_bindings_score(
-            self.get_F10_popup_events(self.post_active_menu_at_top_left,
-                                      self.post_active_menu),
-            switch=switch)
+            self.get_F10_popup_events(
+                self.post_active_menu_at_top_left, self.post_active_menu
+            ),
+            switch=switch,
+        )
         self.set_event_bindings_score(
             self.get_button_events(buttonpress3=self.post_active_menu),
-            switch=switch)
-        
+            switch=switch,
+        )
+
     def set_engine_definition(self, reset_undo=False):
         """Display the chess engine definition as text.
-        
+
         reset_undo causes the undo redo stack to be cleared if True.  Set True
         on first display of an engine definition for editing so that repeated
         Ctrl-Z in text editing mode recovers the original engine definition.
-        
+
         """
         if not self._is_text_editable:
             self.score.configure(state=tkinter.NORMAL)
-        self.score.delete('1.0', tkinter.END)
+        self.score.delete("1.0", tkinter.END)
         self.map_engine_definition()
         if self._most_recent_bindings != NonTagBind.NO_EDITABLE_TAGS:
             self.bind_for_primary_activity()
@@ -94,16 +91,17 @@ class EngineText(SharedTextEngineText, BlankText):
             self.score.configure(state=tkinter.DISABLED)
         if reset_undo:
             self.score.edit_reset()
-        
+
     def set_statusbar_text(self):
         """Set status bar to display chess engine definition name."""
-        #self.ui.statusbar.set_status_text(self.definition.get_name_text())
+        # self.ui.statusbar.set_status_text(self.definition.get_name_text())
 
     def get_name_engine_definition_dict(self):
         """Extract chess engine definition from Text widget."""
         e = Engine()
         if e.extract_engine_definition(
-            self.score.get('1.0', tkinter.END).strip()):
+            self.score.get("1.0", tkinter.END).strip()
+        ):
             return e.__dict__
         return {}
 
@@ -115,8 +113,9 @@ class EngineText(SharedTextEngineText, BlankText):
 
         """
         # No mapping of tokens to text in widget (yet).
-        self.score.insert(tkinter.INSERT,
-                          self.definition.get_name_engine_command_text())
+        self.score.insert(
+            tkinter.INSERT, self.definition.get_name_engine_command_text()
+        )
 
     def run_engine(self, event=None):
         """Run chess engine."""
@@ -132,7 +131,7 @@ class EngineText(SharedTextEngineText, BlankText):
         # At Python3.5 running under Wine on FreeBSD 10.1, get() does not wait
         # when the queue is empty either, and ChessTab does not run under
         # Python3.3 because it uses asyncio: so no point in disabling.
-        #if self.ui.uci.uci_drivers_reply is None:
+        # if self.ui.uci.uci_drivers_reply is None:
         #    tkinter.messagebox.showinfo(
         #        parent=self.panel,
         #        title='Chesstab Restriction',
@@ -145,14 +144,13 @@ class EngineText(SharedTextEngineText, BlankText):
         url = self.definition.engine_url_or_error_message()
         if isinstance(url, str):
             tkinter.messagebox.showerror(
-                parent=self.parent,
-                title='Run Engine',
-                message=url)
+                parent=self.parent, title="Run Engine", message=url
+            )
             return
         if url.query:
             self.ui.run_engine(urlunsplit(url))
         elif url.path:
-            command = url.path.split(' ', 1)
+            command = url.path.split(" ", 1)
             if len(command) == 1:
                 self.ui.run_engine(command[0])
             else:
@@ -160,7 +158,11 @@ class EngineText(SharedTextEngineText, BlankText):
         else:
             tkinter.messagebox.showerror(
                 parent=self.parent,
-                title='Run Engine',
-                message=''.join(
-                    ('Unable to run engine for\n\n',
-                     self.definition.get_engine_command_text())))
+                title="Run Engine",
+                message="".join(
+                    (
+                        "Unable to run engine for\n\n",
+                        self.definition.get_engine_command_text(),
+                    )
+                ),
+            )
