@@ -30,7 +30,7 @@ import tkinter
 
 from .querytext import QueryText
 from .eventspec import EventSpec
-    
+
 
 class Query(QueryText):
 
@@ -44,7 +44,7 @@ class Query(QueryText):
     See superclass for ui, items_manager, and itemgrid, arguments.  These may
     be, or have been, absorbed into **ka argument.
 
-    
+
     """
 
     def __init__(
@@ -54,23 +54,18 @@ class Query(QueryText):
         ui=None,
         items_manager=None,
         itemgrid=None,
-        **ka):
+        **ka
+    ):
         """Create Frame and delegate to superclass, then set grid geometry
         manager.
         """
 
-        panel = tkinter.Frame(
-            master,
-            borderwidth=2,
-            relief=tkinter.RIDGE)
-        panel.bind('<Configure>', self.try_event(self.on_configure))
+        panel = tkinter.Frame(master, borderwidth=2, relief=tkinter.RIDGE)
+        panel.bind("<Configure>", self.try_event(self.on_configure))
         panel.grid_propagate(False)
         super(Query, self).__init__(
-            panel,
-            ui=ui,
-            items_manager=items_manager,
-            itemgrid=itemgrid,
-            **ka)
+            panel, ui=ui, items_manager=items_manager, itemgrid=itemgrid, **ka
+        )
         self.scrollbar.grid(column=1, row=0, rowspan=1, sticky=tkinter.NSEW)
         self.score.grid(column=0, row=0, rowspan=1, sticky=tkinter.NSEW)
         if not ui.visible_scrollbars:
@@ -79,12 +74,12 @@ class Query(QueryText):
 
         # The popup menus specific to Query (placed same as Game equivalent)
 
-        #self.primary_activity_popup.add_cascade(
+        # self.primary_activity_popup.add_cascade(
         #    label='Database', menu=self.database_popup)
 
         # For compatibility with Game when testing if item has focus.
         self.takefocus_widget = self.score
-        
+
     def destroy_widget(self):
         """Destroy the widget displaying game selection rule."""
         self.panel.destroy()
@@ -99,7 +94,7 @@ class Query(QueryText):
     def on_configure(self, event=None):
         """Reconfigure widget after container has been resized."""
         self.configure_selection_widget()
-        
+
     def configure_selection_widget(self):
         """Configure widgets for a game selection rule display."""
         self.panel.grid_rowconfigure(0, weight=1)
@@ -124,27 +119,32 @@ class Query(QueryText):
         # Hack because I misunderstood meaning of takefocus: FALSE does not
         # stop the widget taking focus, just stops tab traversal.
         if take:
-            #self.takefocus_widget.configure(takefocus=tkinter.TRUE)
+            # self.takefocus_widget.configure(takefocus=tkinter.TRUE)
             self.takefocus_widget.configure(takefocus=tkinter.FALSE)
         else:
             self.takefocus_widget.configure(takefocus=tkinter.FALSE)
 
     def set_database_navigation_close_item_bindings(self, switch=True):
         self.set_event_bindings_score(
-            self.get_database_events(), switch=switch)
+            self.get_database_events(), switch=switch
+        )
         self.set_event_bindings_score(
-            self.get_navigation_events(), switch=switch)
+            self.get_navigation_events(), switch=switch
+        )
         self.set_event_bindings_score(
-            self.get_close_item_events(), switch=switch)
+            self.get_close_item_events(), switch=switch
+        )
 
     def set_score_pointer_widget_navigation_bindings(self, switch):
         """Set or unset pointer bindings for widget navigation."""
         self.set_event_bindings_score(
-            ((EventSpec.control_buttonpress_1, ''),
-             (EventSpec.buttonpress_1, self.give_focus_to_widget),
-             (EventSpec.buttonpress_3, self.post_inactive_menu),
-             ),
-            switch=switch)
+            (
+                (EventSpec.control_buttonpress_1, ""),
+                (EventSpec.buttonpress_1, self.give_focus_to_widget),
+                (EventSpec.buttonpress_3, self.post_inactive_menu),
+            ),
+            switch=switch,
+        )
 
     def set_colours(self, sbg, bbg, bfg):
         """Set colours and fonts used to display game selection rule.
@@ -154,7 +154,7 @@ class Query(QueryText):
         bfg == True - set board piece colours
 
         """
-        
+
     def create_primary_activity_popup(self):
         popup = super().create_primary_activity_popup()
         self.create_widget_navigation_submenu_for_popup(popup)
