@@ -17,7 +17,7 @@ from .toplevelpgn import DeletePGN
 
 
 class RepertoireDbDelete(ExceptionHandler, DeletePGN, DataDelete):
-    
+
     """Delete PGN text for repertoire from database.
 
     parent is used as the master argument in a RepertoireToplevel call.
@@ -35,15 +35,15 @@ class RepertoireDbDelete(ExceptionHandler, DeletePGN, DataDelete):
     to be expressed identically and defined once.
 
     """
-    pgn_score_name = 'Repertoire'
+
+    pgn_score_name = "Repertoire"
 
     def __init__(self, parent, oldobject, ui=None):
         """Extend and create toplevel widget for deleting chess game."""
         # Toplevel title set '' in __init__ and to proper value in initialize.
-        super().__init__(oldobject,
-                         parent,
-                         RepertoireToplevel(master=parent, ui=ui),
-                         '')
+        super().__init__(
+            oldobject, parent, RepertoireToplevel(master=parent, ui=ui), ""
+        )
         self.initialize()
 
     @property
@@ -62,7 +62,8 @@ class RepertoireDbDelete(ExceptionHandler, DeletePGN, DataDelete):
         self.set_default_source_for_object(object_)
         view.set_position_analysis_data_source()
         view.collected_game = next(
-            PGN(game_class=view.gameclass).read_games(object_.get_srvalue()))
+            PGN(game_class=view.gameclass).read_games(object_.get_srvalue())
+        )
         view.set_and_tag_item_text()
 
     def get_title_for_object(self, object_=None):
@@ -74,16 +75,20 @@ class RepertoireDbDelete(ExceptionHandler, DeletePGN, DataDelete):
         if object_ is None:
             object_ = self.object
         try:
-            return '  '.join((
-                self.pgn_score_name.join(('Delete ', ':')),
-                object_.value.collected_game._tags[TAG_OPENING],
-                ))
+            return "  ".join(
+                (
+                    self.pgn_score_name.join(("Delete ", ":")),
+                    object_.value.collected_game._tags[TAG_OPENING],
+                )
+            )
         except TypeError:
             return self.pgn_score_name.join(
-                ('Delete ', ' - name unknown or invalid'))
+                ("Delete ", " - name unknown or invalid")
+            )
         except KeyError:
             return self.pgn_score_name.join(
-                ('Delete ', ' - name unknown or invalid'))
+                ("Delete ", " - name unknown or invalid")
+            )
 
     def set_default_source_for_object(self, object_=None):
         """Set default source for Toplevel containing a Repertoire object_.
