@@ -5,9 +5,9 @@
 """Import directory of PGN files with apsw.chessapswdu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..apsw.chessapswdu import chess_sqlite3du
 
-    DirectoryWidget(chess_sqlite3du, 'apsw')
+    DirectoryWidget(chess_sqlite3du, "apsw")
