@@ -5,9 +5,9 @@
 """Import PGN file with apsw.chessapswdu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .file_widget import FileWidget
     from ..apsw.chessapswdu import ChessDatabase
 
-    FileWidget(ChessDatabase, 'apsw')
+    FileWidget(ChessDatabase, "apsw")
