@@ -5,9 +5,9 @@
 """Import directory of PGN files with db.chessdbdu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..db.chessdbdu import chess_dbdu
 
-    DirectoryWidget(chess_dbdu, 'db')
+    DirectoryWidget(chess_dbdu, "db")
