@@ -5,9 +5,9 @@
 """Import directory of PGN files with unqlite.chessunqlitedu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..unqlite.chessunqlitedu import chess_unqlitedu
 
-    DirectoryWidget(chess_unqlitedu, 'unqlite')
+    DirectoryWidget(chess_unqlitedu, "unqlite")
