@@ -5,9 +5,9 @@
 """Import PGN file with unqlite.chessunqlitedu to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .file_widget import FileWidget
     from ..unqlite.chessunqlitedu import ChessDatabase
 
-    FileWidget(ChessDatabase, 'unqlite')
+    FileWidget(ChessDatabase, "unqlite")
