@@ -9,7 +9,7 @@ Table names are changed and extra tables introduced in segment support.
 """
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     import os
 
